@@ -2,6 +2,7 @@ import re
 import json
 from docopt import docopt
 from localstack import config
+from localstack_ext import constants as ext_constants
 from localstack_ext.bootstrap import licensing
 
 
@@ -112,13 +113,24 @@ Commands:
         local_daemon.kill_servers()
 
 
+def cmd_status(argv, args):
+    from localstack.utils.cli import print_status
+    print_status()
+    print('\nExtended Details:')
+    print('------------------')
+    print('Pro Version:\t\t%s' % ext_constants.VERSION)
+    # at this point we can assume that the API key has been validated...
+    print('API Key:\t\tvalidated')
+
+
 def register_commands():
     config.CLI_COMMANDS['daemons'] = {
-        'command': '  localstack daemons',
         'description': 'Manage local daemon processes',
         'parameters': [],
         'function': cmd_daemons
     }
+    if 'status' in config.CLI_COMMANDS:
+        config.CLI_COMMANDS['status']['function'] = cmd_status
 
     # TODO enable commands below?
     return
