@@ -1,18 +1,18 @@
 import os
-rihKg=False
-rihKt=Exception
-rihKb=True
+MGDyA=False
+MGDyV=Exception
+MGDyj=True
 import logging
 import traceback
 import localstack
 from localstack.constants import LOCALSTACK_ROOT_FOLDER
 from localstack.utils.common import(mkdir,run,new_tmp_file,rm_rf,chmod_r,download,unzip,get_arch,in_docker,is_alpine,now)
+from localstack_ext.constants import ARTIFACTS_REPO
 LOG=logging.getLogger(__name__)
 RULE_ENGINE_INSTALL_URL='https://github.com/whummer/serverless-iot-offline'
 H2_DOWNLOAD_URL='http://www.h2database.com/h2-2019-10-14.zip'
 REDIS_URL_PATTERN='https://github.com/whummer/miniredis/raw/master/build/miniredis.<arch>.bin'
-SSL_CERT_URL='https://github.com/localstack/localstack-artifacts/raw/master/local-certs/server.key'
-SSL_CERT_URL_2='https://cdn.jsdelivr.net/gh/localstack/localstack-artifacts/local-certs/server.key'
+SSL_CERT_URL='%s/raw/master/local-certs/server.key'%ARTIFACTS_REPO
 MINIREDIS_BINARY=os.path.join(LOCALSTACK_ROOT_FOLDER,'localstack','infra','redis','miniredis.<arch>.bin')
 INFRA_DIR=os.path.join(os.path.dirname(localstack.__file__),'infra')
 LOCALSTACK_DIR=os.path.dirname(localstack.__file__)
@@ -32,23 +32,23 @@ def install_postgres():
  if not in_docker():
   return
  try:
-  run('which postgres',print_error=rihKg)
- except rihKt:
+  run('which postgres',print_error=MGDyA)
+ except MGDyV:
   install_alpine_package('postgresql','RDS')
  try:
-  run('which pg_config',print_error=rihKg)
- except rihKt:
+  run('which pg_config',print_error=MGDyA)
+ except MGDyV:
   install_alpine_package('postgresql-dev','RDS')
 def install_redis():
  try:
-  run('which redis-server',print_error=rihKg)
- except rihKt:
+  run('which redis-server',print_error=MGDyA)
+ except MGDyV:
   install_alpine_package('redis','ElastiCache')
  return 'redis-server'
 def install_mqtt():
  try:
-  run('which mosquitto',print_error=rihKg)
- except rihKt:
+  run('which mosquitto',print_error=MGDyA)
+ except MGDyV:
   install_alpine_package('mosquitto','IoT')
  return 'mosquitto'
 def install_alpine_package(package,api_name):
@@ -64,14 +64,20 @@ def setup_ssl_cert():
   mod_time=os.path.getmtime(target_file)
   if mod_time>(now()-cache_duration_secs):
    return
- def do_download(url,print_error=rihKg):
+ download_github_artifact(SSL_CERT_URL,target_file)
+def download_github_artifact(url,target_file):
+ def do_download(url,print_error=MGDyA):
   try:
    download(url,target_file)
-   return rihKb
-  except rihKt as e:
+   return MGDyj
+  except MGDyV as e:
    if print_error:
     LOG.info('Unable to download local test SSL certificate from %s to %s: %s %s'%(url,target_file,e,traceback.format_exc()))
- do_download(SSL_CERT_URL)or do_download(SSL_CERT_URL_2,rihKb)
+ result=do_download(url)
+ if not result:
+  url=url.replace('https://github.com','https://cdn.jsdelivr.net/gh')
+  url=url.replace('/raw/master/','/')
+  do_download(url,MGDyj)
 def install_h2():
  target_dir=os.path.join(INFRA_DIR,'h2')
  if not os.path.exists(target_dir):
