@@ -1,20 +1,21 @@
 import os
-SxnmR=Exception
-Sxnmv=False
-Sxnmd=str
-SxnmY=int
-Sxnmp=range
-Sxnmz=len
-SxnmL=object
-Sxnmt=True
+JinXs=Exception
+JinXT=False
+JinXN=str
+JinXl=int
+JinXm=range
+JinXh=len
+JinXW=object
+JinXE=True
 import re
+import sys
 import glob
 import json
 import base64
 import logging
 import pyaes
 from localstack import config as localstack_config
-from localstack.utils.common import(safe_requests as requests,load_file,save_file,to_str,to_bytes,parallelize,get_or_create_file,now_utc,str_insert,str_remove)
+from localstack.utils.common import(safe_requests as requests,load_file,save_file,to_str,to_bytes,md5,parallelize,get_or_create_file,now_utc,str_insert,str_remove)
 from localstack_ext import config
 from localstack_ext.config import PROTECTED_FOLDERS,ROOT_FOLDER
 from localstack_ext.constants import VERSION
@@ -25,7 +26,7 @@ def read_api_key():
  key=os.environ.get('LOCALSTACK_API_KEY')
  if key:
   return key
- raise SxnmR('Unable to retrieve API key. Please configure $LOCALSTACK_API_KEY in your environment')
+ raise JinXs('Unable to retrieve API key. Please configure $LOCALSTACK_API_KEY in your environment')
 def fetch_key():
  api_key=read_api_key()
  if api_key=='test':
@@ -33,36 +34,38 @@ def fetch_key():
  data={'api_key':api_key,'version':VERSION}
  try:
   logging.getLogger('py.warnings').setLevel(logging.ERROR)
-  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=Sxnmv)
+  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=JinXT)
   key_base64=json.loads(result.content)['key']
-  cache_key_locally(key_base64)
- except SxnmR:
-  key_base64=load_cached_key()
+  cache_key_locally(api_key,key_base64)
+ except JinXs:
+  key_base64=load_cached_key(api_key)
  finally:
   logging.getLogger('py.warnings').setLevel(logging.WARNING)
  decoded_key=to_str(base64.b64decode(key_base64))
  return decoded_key
-def cache_key_locally(key_b64):
+def cache_key_locally(api_key,key_b64):
  content=get_or_create_file(localstack_config.CONFIG_FILE_PATH)
  configs=json.loads(to_str(content))
- timestamp=Sxnmd(SxnmY(now_utc()))
+ timestamp=JinXN(JinXl(now_utc()))
  key_raw=to_str(base64.b64decode(key_b64))
- for i in Sxnmp(Sxnmz(timestamp)):
+ for i in JinXm(JinXh(timestamp)):
   key_raw=str_insert(key_raw,i*2,timestamp[i])
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
- configs['cached_key']={'timestamp':SxnmY(timestamp),'key':key_b64}
+ configs['cached_key']={'timestamp':JinXl(timestamp),'key_hash':md5(api_key),'key':key_b64}
  save_file(localstack_config.CONFIG_FILE_PATH,json.dumps(configs))
  return configs
-def load_cached_key():
+def load_cached_key(api_key):
  content=get_or_create_file(localstack_config.CONFIG_FILE_PATH)
  configs=json.loads(to_str(content))
  cached_key=configs['cached_key']
+ if cached_key.get('key_hash')!=md5(api_key):
+  raise JinXs('Cached key was created for a different API key')
  now=now_utc()
  if(now-cached_key['timestamp'])>MAX_KEY_CACHE_DURATION_SECS:
-  raise SxnmR('Cached key expired')
- timestamp=Sxnmd(cached_key['timestamp'])
+  raise JinXs('Cached key expired')
+ timestamp=JinXN(cached_key['timestamp'])
  key_raw=to_str(base64.b64decode(cached_key['key']))
- for i in Sxnmp(Sxnmz(timestamp)):
+ for i in JinXm(JinXh(timestamp)):
   assert key_raw[i]==timestamp[i]
   key_raw=str_remove(key_raw,i)
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
@@ -101,11 +104,11 @@ def cleanup_environment():
       if os.path.exists(delete_file):
        os.remove(delete_file)
 def prepare_environment():
- class OnClose(SxnmL):
+ class OnClose(JinXW):
   def __exit__(self,*args,**kwargs):
    if not ENV_PREPARED.get('finalized'):
     cleanup_environment()
-   ENV_PREPARED['finalized']=Sxnmt
+   ENV_PREPARED['finalized']=JinXE
   def __enter__(self,*args,**kwargs):
    pass
  if not ENV_PREPARED.get('finalized'):
@@ -114,7 +117,10 @@ def prepare_environment():
    if key!='test':
     decrypt_files(key)
     LOG.info('Successfully activated API key')
-  except SxnmR:
+  except JinXs:
+   if config.REQUIRE_PRO:
+    LOG.error('Unable to activate API key, but $REQUIRE_PRO is configured - quitting.')
+    sys.exit(1)
    pass
  return OnClose()
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
