@@ -1,26 +1,26 @@
 #!/usr/bin/env python
-BqApX=dict
-BqAps=super
-BqApL=hasattr
-BqApv=Exception
-BqApe=object
-BqApm=dir
-BqApt=None
-BqApP=False
-BqApy=True
-BqApw=len
-BqApg=set
+rCHkj=dict
+rCHkL=super
+rCHkp=hasattr
+rCHkT=Exception
+rCHka=object
+rCHkI=dir
+rCHkW=None
+rCHkB=False
+rCHkl=True
+rCHky=len
+rCHkb=set
 import errno
 import socket
 from select import select
 from socket import(AF_INET,AF_INET6,SOCK_STREAM,IPV6_V6ONLY,SO_REUSEADDR,IPPROTO_TCP,IPPROTO_IPV6,TCP_NODELAY,SOL_SOCKET)
-class AttrDict(BqApX):
+class AttrDict(rCHkj):
  def __init__(self,*args,**kwargs):
-  BqAps(AttrDict,self).__init__(*args,**kwargs)
+  rCHkL(AttrDict,self).__init__(*args,**kwargs)
   self.__dict__=self
 def tcp_listen(six,addr,port,blk):
  s=socket.socket(AF_INET6 if six else AF_INET,SOCK_STREAM)
- if six and BqApL(socket,'IPV6_V6ONLY'):
+ if six and rCHkp(socket,'IPV6_V6ONLY'):
   s.setsockopt(IPPROTO_IPV6,IPV6_V6ONLY,0)
  s.setsockopt(SOL_SOCKET,SO_REUSEADDR,1)
  s.setsockopt(IPPROTO_TCP,TCP_NODELAY,1)
@@ -37,9 +37,9 @@ def tcp_connect(six,addr,port,blk):
 def safe_close(x):
  try:
   x.close()
- except BqApv:
+ except rCHkT:
   pass
-class Server(BqApe):
+class Server(rCHka):
  def __init__(self,opt,q):
   self.opt=opt
   self.sock=tcp_listen(opt.ip6,opt.bind_addr,opt.bind_port,0)
@@ -51,17 +51,17 @@ class Server(BqApe):
    cl,addr=self.sock.accept()
    cl.setblocking(0)
    self.q.append(Proxy(self.opt,cl,addr))
-class Half(BqApe):
- def __init__(self,opt,sock,addr,BqApm):
+class Half(rCHka):
+ def __init__(self,opt,sock,addr,rCHkI):
   self.opt=opt
   self.sock=sock
   self.addr=addr
-  self.BqApm=BqApm
-  self.name='peer' if self.BqApm else 'client'
+  self.rCHkI=rCHkI
+  self.name='peer' if self.rCHkI else 'client'
   self.queue=[]
-  self.dest=BqApt
-  self.err=BqApt
-  self.ready=BqApP
+  self.dest=rCHkW
+  self.err=rCHkW
+  self.ready=rCHkB
  def pre_wait(self,rr,r,w,e):
   if self.ready:
    rr.append(self.sock)
@@ -72,7 +72,7 @@ class Half(BqApe):
   if not self.err and self.sock in w and self.queue:
    self.write_some()
   if not self.err and self.sock in r:
-   self.ready=BqApy
+   self.ready=rCHkl
    self.copy()
   return self.err
  def error(self,msg,e):
@@ -81,9 +81,9 @@ class Half(BqApe):
  def write_some(self):
   try:
    n=self.sock.send(self.queue[0])
-  except BqApv as e:
+  except rCHkT as e:
    return self.error('send error',e)
-  if n!=BqApw(self.queue[0]):
+  if n!=rCHky(self.queue[0]):
    self.queue[0]=self.queue[0][n:]
   else:
    del self.queue[0]
@@ -92,17 +92,17 @@ class Half(BqApe):
    buf=self.sock.recv(4096)
   except socket.error as e:
    if e.errno==errno.EWOULDBLOCK:
-    self.ready=BqApP
+    self.ready=rCHkB
     return
    return self.error('recv socket error',e)
-  except BqApv as e:
+  except rCHkT as e:
    return self.error('recv error',e)
-  if BqApw(buf)==0:
+  if rCHky(buf)==0:
    return self.error('eof',0)
   self.dest.queue.append(buf)
  def close(self):
   safe_close(self.sock)
-class Proxy(BqApe):
+class Proxy(rCHka):
  def __init__(self,opt,sock,addr):
   self.opt=opt
   self.cl=Half(opt,sock,addr,'i')
@@ -110,7 +110,7 @@ class Proxy(BqApe):
   self.peer=Half(opt,peer,addr,'o')
   self.cl.dest=self.peer
   self.peer.dest=self.cl
-  self.err=BqApt
+  self.err=rCHkW
  def pre_wait(self,rr,r,w,e):
   self.cl.pre_wait(rr,r,w,e)
   self.peer.pre_wait(rr,r,w,e)
@@ -125,7 +125,7 @@ class Proxy(BqApe):
   return self.err
 def server_loop(opt):
  qs=[]
- opt['ip6']=opt.get('ip6',BqApP)
+ opt['ip6']=opt.get('ip6',rCHkB)
  opt['bind_addr']=opt.get('bind_addr','0.0.0.0')
  opt['addr']=opt.get('addr','127.0.0.1')
  opt['bind_port']=opt.get('bind_port',0)
@@ -137,15 +137,15 @@ def server_loop(opt):
    q.pre_wait(rr,r,w,e)
   timeo=10.0 if not rr else 0.0
   r,w,e=select(r,w,e,timeo)
-  r=BqApg(r).union(rr)
+  r=rCHkb(r).union(rr)
   for q in qs:
    if q.post_wait(r,w,e):
     qs.remove(q)
 def main():
- opt={'ip6':BqApP,'bind_port':2223,'addr':'192.168.43.191','port':22}
- opt={'ip6':BqApP,'bind_port':48429,'addr':'128.0.100.3','port':22}
- opt={'ip6':BqApP,'port':54237,'bind_addr':'128.0.100.2','bind_port':22}
- opt={'ip6':BqApP,'port':54237,'bind_addr':'192.168.100.3','bind_port':22}
+ opt={'ip6':rCHkB,'bind_port':2223,'addr':'192.168.43.191','port':22}
+ opt={'ip6':rCHkB,'bind_port':48429,'addr':'128.0.100.3','port':22}
+ opt={'ip6':rCHkB,'port':54237,'bind_addr':'128.0.100.2','bind_port':22}
+ opt={'ip6':rCHkB,'port':54237,'bind_addr':'192.168.100.3','bind_port':22}
  server_loop(opt)
 if __name__=='__main__':
  main()
