@@ -80,6 +80,9 @@ ENFORCE_IAM = localstack_config.is_env_true('ENFORCE_IAM')
 # folder with persistent API backend states
 BACKEND_STATES_DIR = os.path.join(localstack_config.DATA_DIR, 'api_states')
 
+# whether to require Pro features and exit with a fault if the API key cannot be activated
+REQUIRE_PRO = localstack_config.is_env_true('REQUIRE_PRO')
+
 
 def use_custom_dns():
     return str(DNS_ADDRESS) not in FALSE_STRINGS
@@ -97,15 +100,11 @@ DEFAULT_PORT_LOCAL_DAEMON_ROOT = 4534
 SERVICE_INSTANCES_PORTS_START = 4510
 SERVICE_INSTANCES_PORTS_END = SERVICE_INSTANCES_PORTS_START + 20
 
-# add default service ports (TODO remove)
-localstack_constants.DEFAULT_SERVICE_PORTS['cognito-idp'] = 4590
-localstack_constants.DEFAULT_SERVICE_PORTS['cognito-identity'] = 4591
-localstack_constants.DEFAULT_SERVICE_PORTS['sts'] = 4592
-localstack_constants.DEFAULT_SERVICE_PORTS['iam'] = 4593
-localstack_constants.DEFAULT_SERVICE_PORTS['azure'] = 12121
-
 PORT_AZURE = 12121
 
+# add default service ports (TODO needed?)
+localstack_constants.DEFAULT_SERVICE_PORTS['azure'] = PORT_AZURE
+
 # Docker host name resolvable from containers
 DOCKER_HOST_NAME = 'host.docker.internal'
 
@@ -132,7 +131,8 @@ if localstack_config.DOCKER_HOST_FROM_CONTAINER == DOCKER_HOST_NAME:
 # update variable names that need to be passed as arguments to Docker
 localstack_config.CONFIG_ENV_VARS += [
     'SMTP_HOST', 'SMTP_USER', 'SMTP_PASS', 'SMTP_EMAIL', 'DNS_SERVER', 'DNS_ADDRESS', 'ENFORCE_IAM',
-    'DNS_RESOLVE_IP', 'DNS_LOCAL_NAME_PATTERNS', 'AUTOSTART_UTIL_CONTAINERS', 'CLOUDFRONT_STATIC_PORTS'
+    'DNS_RESOLVE_IP', 'DNS_LOCAL_NAME_PATTERNS', 'AUTOSTART_UTIL_CONTAINERS', 'CLOUDFRONT_STATIC_PORTS',
+    'REQUIRE_PRO', 'AZURE'
 ]
 
 # re-initialize configs in localstack
