@@ -1,9 +1,11 @@
 import os
-kADas=Exception
-kADav=any
-kADaT=str
-kADar=None
-kADaY=True
+IGWql=Exception
+IGWqw=any
+IGWqU=str
+IGWqj=None
+IGWqC=False
+IGWqF=bool
+IGWqm=True
 import logging
 from localstack import config as localstack_config
 from localstack.utils import common
@@ -27,14 +29,14 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except kADas:
+  except IGWql:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled('ec2'):
     local_daemon.start_in_background()
-  except kADas as e:
+  except IGWql as e:
    LOG.warning('Unable to start local daemon process: %s'%e)
   if is_api_key_configured and not os.environ.get('EDGE_PORT'):
    port=localstack_config.EDGE_PORT
@@ -57,12 +59,14 @@ def register_localstack_plugins():
    docker_flags+=['-p {a}:{p}:{p}'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols='udp'):
    docker_flags+=['-p {a}:{p}:{p}/udp'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if kADav([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if IGWqw([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=['-p {start}-{end}:{start}-{end}'.format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled('eks'):
   kube_config=os.path.expanduser('~/.kube/config')
   if os.path.exists(kube_config):
    docker_flags+=['-v %s:/root/.kube/config'%kube_config]
+ if os.environ.get('AZURE'):
+  docker_flags+=['-p {p}:{p}'.format(p=config_ext.PORT_AZURE)]
  result={'docker':{'run_flags':' '.join(docker_flags)}}
  return result
 def load_plugin_files():
@@ -105,6 +109,8 @@ def load_plugin_files():
   from localstack_ext.services.transfer import transfer_starter
   from localstack_ext.services.mediastore import mediastore_starter
   from localstack_ext.services.iam import iam_extended
+  from localstack_ext.services.dynamodb import dynamodb_extended
+  from localstack_ext.services.events import events_extended
   from localstack_ext.services.kafka import kafka_starter
   from localstack_ext.services.kinesisanalytics import kinesis_analytics_api
   from localstack_ext.services import edge
@@ -153,26 +159,33 @@ def load_plugin_files():
   stepfunctions_extended.patch_stepfunctions()
   s3_extended.patch_s3()
   iam_extended.patch_iam()
+  dynamodb_extended.patch_dynamodb()
+  events_extended.patch_events()
   dashboard_extended.patch_dashboard()
   aws_utils.patch_aws_stack()
   edge.patch_start_edge()
   patch_start_infra()
- except kADas as e:
-  if 'No module named' not in kADaT(e):
+ except IGWql as e:
+  if 'No module named' not in IGWqU(e):
    print(e)
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except kADas:
-  start_metadata_service=kADar
+ except IGWql:
+  start_metadata_service=IGWqj
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except kADas:
+   except IGWql:
     pass
-  return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
+  enforce_before=config_ext.ENFORCE_IAM
+  try:
+   config_ext.ENFORCE_IAM=IGWqC
+   return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
+  finally:
+   config_ext.ENFORCE_IAM=enforce_before
  do_start_infra_orig=infra.do_start_infra
  infra.do_start_infra=do_start_infra
 def _setup_logging():
@@ -186,9 +199,9 @@ def _setup_logging():
  logging.getLogger('jnius.reflect').setLevel(logging.INFO)
  logging.getLogger('dulwich').setLevel(logging.ERROR)
 def api_key_configured():
- return os.environ.get('LOCALSTACK_API_KEY')
+ return IGWqF(os.environ.get('LOCALSTACK_API_KEY'))
 def register_localstack_commands():
  if api_key_configured():
   cli.register_commands()
- return kADaY
+ return IGWqm
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
